CCL: Globals

CCL

### - c -

- calculate_nu_phasespace_spline() : ccl_neutrinos.c , ccl_neutrinos.h
- ccl_angular_cl() : ccl_cls.h , ccl_cls.c
- ccl_check_status() : ccl_error.c , ccl_error.h
- ccl_check_status_nocosmo() : ccl_error.h , ccl_error.c
- ccl_cl_tracer_free() : ccl_cls.c , ccl_cls.h
- ccl_cl_tracer_lensing_new() : ccl_cls.c , ccl_cls.h
- ccl_cl_tracer_lensing_simple_new() : ccl_cls.c , ccl_cls.h
- ccl_cl_tracer_new() : ccl_cls.h , ccl_cls.c
- ccl_cl_tracer_number_counts_new() : ccl_cls.c , ccl_cls.h
- ccl_cl_tracer_number_counts_simple_new() : ccl_cls.c , ccl_cls.h
- ccl_comoving_angular_distance() : ccl_background.c , ccl_background.h
- ccl_comoving_angular_distances() : ccl_background.c , ccl_background.h
- ccl_comoving_radial_distance() : ccl_background.c , ccl_background.h
- ccl_comoving_radial_distances() : ccl_background.c , ccl_background.h
- ccl_cosmology_compute_distances() : ccl_background.c , ccl_core.h
- ccl_cosmology_compute_growth() : ccl_core.h , ccl_background.c
- ccl_cosmology_compute_hmfparams() : ccl_massfunc.c , ccl_massfunc.h
- ccl_cosmology_compute_power() : ccl_power.c , ccl_core.h
- ccl_cosmology_compute_sigma() : ccl_massfunc.c , ccl_massfunc.h
- ccl_cosmology_create() : ccl_core.c , ccl_core.h
- ccl_cosmology_create_with_lcdm_params() : ccl_core.c , ccl_core.h
- ccl_cosmology_create_with_params() : ccl_core.c , ccl_core.h
- ccl_cosmology_free() : ccl_core.c , ccl_core.h
- ccl_cosmology_read_config() : ccl_core.c , ccl_core.h
- ccl_data_free() : ccl_core.c
- ccl_distance_moduli() : ccl_background.c , ccl_background.h
- ccl_distance_modulus() : ccl_background.c , ccl_background.h
- ccl_growth_factor() : ccl_background.c , ccl_background.h
- ccl_growth_factor_unnorm() : ccl_background.c , ccl_background.h
- ccl_growth_factors() : ccl_background.c , ccl_background.h
- ccl_growth_factors_unnorm() : ccl_background.c , ccl_background.h
- ccl_growth_rate() : ccl_background.c , ccl_background.h
- ccl_growth_rates() : ccl_background.c , ccl_background.h
- ccl_h_over_h0() : ccl_background.c , ccl_background.h
- ccl_h_over_h0s() : ccl_background.c , ccl_background.h
- ccl_halo_bias() : ccl_massfunc.c , ccl_massfunc.h
- ccl_linear_matter_power() : ccl_power.c , ccl_power.h
- ccl_linear_spacing() : ccl_utils.c , ccl_utils.h
- ccl_log_spacing() : ccl_utils.c , ccl_utils.h
- ccl_luminosity_distance() : ccl_background.c , ccl_background.h
- ccl_luminosity_distances() : ccl_background.c , ccl_background.h
- ccl_massfunc() : ccl_massfunc.c , ccl_massfunc.h
- ccl_massfunc_m2r() : ccl_massfunc.c , ccl_massfunc.h
- ccl_nonlin_matter_power() : ccl_power.c , ccl_power.h
- ccl_omega_x() : ccl_background.c , ccl_background.h
- ccl_parameters_create() : ccl_core.c , ccl_core.h
- ccl_parameters_create_flat_lcdm() : ccl_core.c , ccl_core.h
- ccl_parameters_create_flat_lcdm_nu() : ccl_core.h , ccl_core.c
- ccl_parameters_create_flat_wacdm() : ccl_core.c , ccl_core.h
- ccl_parameters_create_flat_wacdm_nu() : ccl_core.c , ccl_core.h
- ccl_parameters_create_flat_wcdm() : ccl_core.c , ccl_core.h
- ccl_parameters_create_flat_wcdm_nu() : ccl_core.h , ccl_core.c
- ccl_parameters_create_lcdm() : ccl_core.c , ccl_core.h
- ccl_parameters_create_lcdm_nu() : ccl_core.h , ccl_core.c
- ccl_parameters_fill_initial() : ccl_core.c
- ccl_raise_exception() : ccl_error.c , ccl_error.h
- ccl_scale_factor_of_chi() : ccl_background.c , ccl_background.h
- ccl_scale_factor_of_chis() : ccl_background.c , ccl_background.h
- ccl_set_error_policy() : ccl_error.c , ccl_error.h
- ccl_sigma8() : ccl_power.c , ccl_power.h
- ccl_sigmaM() : ccl_massfunc.c , ccl_massfunc.h
- ccl_sigmaR() : ccl_power.c , ccl_power.h
- ccl_sinn() : ccl_background.c , ccl_background.h
- ccl_specs_bias_clustering() : ccl_lsst_specs.c , ccl_lsst_specs.h
- ccl_specs_create_photoz_info() : ccl_lsst_specs.h , ccl_lsst_specs.c
- ccl_specs_dNdz_tomog() : ccl_lsst_specs.c , ccl_lsst_specs.h
- ccl_specs_free_photoz_info() : ccl_lsst_specs.h , ccl_lsst_specs.c
- ccl_specs_sigmaz_clustering() : ccl_lsst_specs.c , ccl_lsst_specs.h
- ccl_specs_sigmaz_sources() : ccl_lsst_specs.h , ccl_lsst_specs.c
- CTEST() : ccl_test_utils.c
- CTEST2() : ccl_test_cls.c , ccl_test_growth.c , ccl_test_distances.c , ccl_test_growth.c , ccl_test_sigmaM.c , ccl_test_cosmology.c , ccl_test_growth.c , ccl_test_eh.c , ccl_test_distances.c , ccl_test_sigmaM.c , ccl_test_growth.c , ccl_test_params.c , ccl_test_sigmaM.c , ccl_test_bbks.c , ccl_test_distances.c , ccl_test_bbks.c , ccl_test_cls.c , ccl_test_bbks.c , ccl_test_params.c , ccl_test_distances.c , ccl_test_growth.c , ccl_test_massfunc.c , ccl_test_growth.c
- CTEST_DATA() : ccl_test_cls.c , ccl_test_cosmology.c , ccl_test_eh.c , ccl_test_bbks.c , ccl_test_massfunc.c , ccl_test_sigmaM.c , ccl_test_growth.c , ccl_test_params.c , ccl_test_distances.c
- CTEST_ERR() : ctest.h
- CTEST_LOG() : ctest.h
- CTEST_SETUP() : ccl_test_sigmaM.c , ccl_test_cls.c , ccl_test_growth.c , ccl_test_distances.c , ccl_test_params.c , ccl_test_cosmology.c , ccl_test_massfunc.c , ccl_test_eh.c , ccl_test_bbks.c